config

package
v0.0.0-...-481a8b4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 9, 2018 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BaseConfig

type BaseConfig struct {
	// The root directory for all data.
	// This should be set in viper so it can unmarshal into this struct
	RootDir string `mapstructure:"home"`
}

func DefaultBaseConfig

func DefaultBaseConfig() BaseConfig

type EthermintConfig

type EthermintConfig struct {
	EthChainId        uint   `mapstructure:"eth_chain_id"`
	RootDir           string `mapstructure:"home"`
	ABCIAddr          string `mapstructure:"abci_laddr"`
	ABCIProtocol      string `mapstructure:"abci_protocol"`
	RPCEnabledFlag    bool   `mapstructure:"rpc"`
	RPCListenAddrFlag string `mapstructure:"rpcaddr"`
	RPCPortFlag       uint   `mapstructure:"rpcport"`
	RPCCORSDomainFlag string `mapstructure:"rpccorsdomain"`
	RPCApiFlag        string `mapstructure:"rpcapi"`
	WSEnabledFlag     bool   `mapstructure:"ws"`
	WSListenAddrFlag  string `mapstructure:"wsaddr"`
	WSPortFlag        uint   `mapstructure:"wsport"`
	WSApiFlag         string `mapstructure:"wsapi"`
	VerbosityFlag     uint   `mapstructure:"verbosity"`
}

func DefaultEthermintConfig

func DefaultEthermintConfig() EthermintConfig

type TConfig

type TConfig struct {
	RepeatTxTest         bool `mapstructure:"repeat_tx_test"`
	TxSameAccount        bool `mapstructure:"tx_same_account"`
	TxMultiAccount       bool `mapstructure:"tx_multi_account"`
	RepeastSendSleep     uint `mapstructure:"repeat_send_sleep"`
	ContractSameAccount  bool `mapstructure:"contract_same_account"`
	ContractMultiAccount bool `mapstructure:"contract_multi_account"`
	PrintConsensusLog    bool `mapstructure:"print_consensus_log"`
	PrintSendRecvLog     bool `mapstructure:"print_sendrecv_log"`
	PrintPtxLog          bool `mapstructure:"ptx_detail_log"`
	ForceValidator       bool `mapstructure:"force_validator"`
	CompactBlock         bool `mapstructure:"tm_compact_block"`
	BuildFullBlock       bool `mapstructure:"build_full_block"`   // use compact block build full block
	UsePtxHash           bool `mapstructure:"broadcast_ptx_hash"` // broadcast ptx with hash or ptx with tx
	PtxCyclePeriod       uint `mapstructure:"ptx_cycle_period"`
	DisablePtx           bool `mapstructure:"disable_ptx"`
	ReplayTxInMempool    uint `mapstructure:"replay_tx_mempool"` // 0: disable, 1:same tx 2:loop tx ...
	ReplayNumEpoch       int  `mapstructure:"replay_num_epoch"`
}

func DefaultTestConfig

func DefaultTestConfig() TConfig

type UltronConfig

type UltronConfig struct {
	BaseConfig BaseConfig      `mapstructure:",squash"`
	TMConfig   tmcfg.Config    `mapstructure:",squash"`
	EMConfig   EthermintConfig `mapstructure:"vm"`
	TestConfig TConfig         `mapstructure:"test"`
}

func DefaultConfig

func DefaultConfig() *UltronConfig

func ParseConfig

func ParseConfig() (*UltronConfig, error)

ParseConfig retrieves the default environment configuration, sets up the Tendermint root and ensures that the root exists

Jump to